pub struct RequestIdentifier { /* private fields */ }
A middleware for generating per-request unique IDs

Implementations

Create a default middleware using DEFAULT_HEADER as the header name and UUID v4 for ID generation.

Create a middleware using a custom header name and UUID v4 for ID generation.

Change the header name for this middleware.

Create a middleware using DEFAULT_HEADER as the header name and IDs as generated by id_generator. id_generator should return a unique ID (ASCII only), each time it is invoked.

Change the ID generator for this middleware.

Change the behavior for incoming request id headers. When this is set to IdReuse::UseIncoming (the default), each request is checked if it contains a header by the specified name and if it exists, the id from that header is used, otherwise a random id is generated. When this is set to IdReuse::IgnoreIncoming, the id from the request header is ignored.